<?php

declare(strict_types=1);

namespace Drupal\views_entity_form_row;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

final class FormOperations implements ContainerInjectionInterface {

  private ViewsEntityFormRowInfo $viewsEntityFormRowInfo;
  private RouteMatchInterface $currentRouteMatch;

  public function __construct(ViewsEntityFormRowInfo $views_entity_form_row_info, RouteMatchInterface $current_route_match) {
    $this->viewsEntityFormRowInfo = $views_entity_form_row_info;
    $this->currentRouteMatch = $current_route_match;
  }

  public static function create(ContainerInterface $container): self {
    return new self(
      $container->get('views_entity_form_row.info'),
      $container->get('current_route_match')
    );
  }

  public function nodeFormAlter(array &$form, FormStateInterface $form_state, string $form_id): void {
    if (!$this->viewsEntityFormRowInfo->isPluginUsedInCurrentView()) {
      return;
    }
    $form['actions']['submit']['#submit'][] = [
      $this,
      'redirectToCurrentPageSubmit',
    ];
  }

  public function redirectToCurrentPageSubmit(array &$form, FormStateInterface $form_state): void {
    $url = Url::fromRouteMatch($this->currentRouteMatch);
    $form_state->setRedirectUrl($url);
  }

}
